==> laravel-elixir-svg-sprite-0.1.2.tgz: package/index.js <==
var gulp = require('gulp'),
    rename = require('gulp-rename'),
    svgSprite = require('gulp-svg-sprite'),
    elixir = require('laravel-elixir'),
    notifications = require('laravel-elixir/ingredients/commands/Notification'),
    utilities = require('laravel-elixir/ingredients/commands/Utilities'),
    _ = require('underscore');

elixir.extend('svgSprite', function (options) {

    var config = this,
        defaultOptions = {
            outputDir: './public/',
            rename: 'svg-include',
            srcDir: './resources/svg/',
            bladePartialDir: './resources/views/partials',
            bladePartial: 'svg-inline'
        };

    options = _.extend(defaultOptions, options);

    gulp.task('svgSprite', function () {

        var onError = function (e) {
            new notifications().error(e, 'SVG Sprite sprite sheet creation failed');
            this.emit('end');
        };

        gulp.src(options.srcDir + '/**/*.svg')
            .pipe(svgSprite(options))
            .on('error', onError)
            .pipe(rename({basename: options.rename}))
            .pipe(gulp.dest(options.outputDir))
            .pipe(new notifications().message('SVG Sprite sprite sheet created in ' + options.outputDir));


        if (options.bladePartial != false) {
            gulp.src(options.outputDir + '/svg/' + options.rename + '.svg')
                .pipe(rename(options.bladePartial + '.blade.php'))
                .pipe(gulp.dest(options.bladePartialDir))
                .pipe(new notifications().message('Blade partial copied to ' + options.bladePartialDir + '/' + options.bladePartial));
        }

        return;

    });

    this.registerWatcher('svgSprite', options.srcDir + '/**/*.svg');

    return this.queueTask('svgSprite');
});

==> laravel-elixir-svg-sprite-0.1.4.tgz: package/index.js <==
var gulp = require('gulp'),
    rename = require('gulp-rename'),
    svgSprite = require('gulp-svg-sprite'),
    elixir = require('laravel-elixir'),
    notifications = require('laravel-elixir/ingredients/commands/Notification'),
    utilities = require('laravel-elixir/ingredients/commands/Utilities'),
    _ = require('underscore');

elixir.extend('svgSprite', function (options) {

    var config = this,
        defaultOptions = {
            outputDir: './public/',
            rename: 'svg-include',
            srcDir: './resources/svg/',
            bladePartialDir: './resources/views/partials',
            bladePartial: 'svg-include'
        };

    options = _.extend(defaultOptions, options);

    gulp.task('svgSprite', function () {

        var onError = function (e) {
            new notifications().error(e, 'SVG Sprite sprite sheet creation failed');
            this.emit('end');
        };

        gulp.src(options.srcDir + '/**/*.svg')
            .pipe(svgSprite(options))
            .on('error', onError)
            .pipe(rename({basename: options.rename}))
            .pipe(gulp.dest(options.outputDir))
            .pipe(new notifications().message('SVG Sprite sprite sheet created in ' + options.outputDir));


        if (options.bladePartial != false) {
            gulp.src(options.outputDir + '/svg/' + options.rename + '.svg')
                .pipe(rename(options.bladePartial + '.blade.php'))
                .pipe(gulp.dest(options.bladePartialDir))
                .pipe(new notifications().message('Blade partial copied to ' + options.bladePartialDir + '/' + options.bladePartial));
        }

        return;

    });

    this.registerWatcher('svgSprite', options.srcDir + '/**/*.svg');

    return this.queueTask('svgSprite');
});
